AvifDecoder

Struct AvifDecoder 

pub struct AvifDecoder<R> { /* private fields */ }
Available on (crate features avif or avif-native) and crate feature avif-native only.
The AVIF specification defines an image derivative of the AV1 bitstream, an open video codec.

AVIF Decoder.

Reads one image into the chosen input.

Implementations

Source

impl<R: Read> AvifDecoder<R>

pub fn new(r: R) -> ImageResult<Self>

Create a new decoder that reads its input from r.