pub fn register_decoding_hook(extension: OsString, hook: DecodingHook) -> boolAvailable on crate feature
std only.Expand description
Register a new decoding hook or returns false if one already exists for the given format.
pub fn register_decoding_hook(extension: OsString, hook: DecodingHook) -> boolstd only.Register a new decoding hook or returns false if one already exists for the given format.